@@ -16,7 +16,8 @@ $apt_cache $apt_source $home $host_config $mirror $verbose @dirs
 @EXPORT=qw( srclookup binlookup cache_update get_cache_iter get_cachedir
 deplookup force_update check_update setup_config set_cachedir
 update_sources prepare_sources_list get_aptcross_dir init_cache
-get_verbose set_mirror set_verbose init_host_cache ver_compare );
+get_verbose set_mirror set_verbose init_host_cache ver_compare 
+clear_config );
 
 =pod
 
@@ -212,6 +213,18 @@ sub init_cache
 	return $config;
 }
 
+=head1 clear_config
+
+Completely clears the current config in preparation for a new
+set of &check_cache_arch, &set_suite and &init_cache;
+
+=cut
+
+sub clear_config
+{
+	undef $config;
+}
+
 =head1 srclookup($package_name)
 
 Look up a package name in the source cache and return the
@@ -588,11 +601,17 @@ sub cache_update {
 	if (defined($self))
 	{
 		print "cache_update: " . Dumper($self) if ($verbose >=4);
-		system(" apt-get ".$self->{main}->{'config_str'}." update 2>/dev/null");
+		system(" apt-get ".$self->{main}->{'config_str'}." update 2>/dev/null")
+			if ($verbose >= 2);
+		system(" apt-get ".$self->{main}->{'config_str'}." update &>/dev/null")
+			if ($verbose < 2);
 	}
 	&aptinit($self, $verbose);
 	return unless defined($host_config);
-	system(" apt-get ".$host_config->{main}->{'config_str'}." update 2>/dev/null");
+	system(" apt-get ".$host_config->{main}->{'config_str'}." update 2>/dev/null")
+		if ($verbose >= 2);
+	system(" apt-get ".$host_config->{main}->{'config_str'}." update &>/dev/null")
+		if ($verbose < 2);
 	&aptinit($host_config, $verbose);
 }
 
@@ -761,19 +780,60 @@ sub get_depends {
 sub file_depends {
 	my $results = shift(@_);
 	my $deps = shift(@_);
+	my $flag = 0;
+	my @orlist = ();
+	my $tag = "";
+	my $or_ver = "";
 
-	for my $dep (@$deps) {
+	for my $dep (@$deps)
+	{
+		# get the comparison operator
+		my $op = ($dep->{CompTypeDeb}) ? $dep->{CompTypeDeb} : 
+			print_depcompareop ($dep->{CompType});
+		$op = "" if (not defined $op);
+		$tag = $op if ($flag == 0);
 		# Figure out the version.
 		my $version = ($reverse ? $dep->{ParentVer}->{VerStr} : $dep->{TargetVer});
-		if ($version) {
-			$version = ($dep->{CompTypeDeb} ? $dep->{CompTypeDeb} . " " : "") . $version;
+		# Figure out the current state.
+		my $state = ($reverse ? $dep->{ParentPkg}->{CurrentState} :
+			$dep->{TargetPkg}->{CurrentState});
+		# if $op eq "|", need to concatenate until $op != "|"
+		# hack-alert for debconf
+		if (($dep->{$PkgReference}->{Name} eq "debconf") and $op ne "|")
+		{
+			warn "W: debconf operator hack alert" if ($verbose >= 4);
+			$tag = $op;
+			$op = "|";
+			$flag++;
 		}
-	# Figure out the current state.
-	my $state = ($reverse ? $dep->{ParentPkg}->{CurrentState} : $dep->{TargetPkg}->{CurrentState});
-	# Push the name of this package into the right pigeonhole.
-	$$results{0+$dep->{DepType}}{$dep->{$PkgReference}->{Name}} = [ $version, $state, "$dep->{DepType}"];
-	# Populate the dictionaries of names for this lcoale
-	$deptype_dict{0+$dep->{DepType}} = lc("$dep->{DepType}");
+		if ($op eq "|")
+		{
+			$flag++;
+			$or_ver = $dep->{$PkgReference}->{Name};
+			$or_ver .= " ($tag $version)" if (defined $version);
+			# hack alert
+			if (($dep->{$PkgReference}->{Name} eq "debconf")
+			 and ($or_ver !~ /\(.*\)/))
+			{
+				$or_ver .= " (>= 0.5)";
+				warn "W: debconf: version hack alert" if ($verbose >= 4);
+			}
+			$tag = $op;
+			push @orlist, $or_ver;
+		}
+		else
+		{
+			push @orlist, $dep->{$PkgReference}->{Name} if ($flag > 0);
+			$flag = 0;
+			# Push the name of this package into the right pigeonhole.
+			$$results{0+$dep->{DepType}}{$dep->{$PkgReference}->{Name}} = 
+				[ $version, $state, "$dep->{DepType}", $tag, join(" | ", @orlist) ];
+			@orlist = ();
+		}
+		# Populate the dictionaries of names for this locale
+		$deptype_dict{0+$dep->{DepType}} = lc("$dep->{DepType}");
+		print Dumper ($$results{0+$dep->{DepType}}{$dep->{$PkgReference}->{Name}})
+			if ($verbose >= 4);
 	}
 }
 
